@@ -180,6 +180,16 @@ class AsyncKafkaSubscriber(AsyncSubscriber):
         )
         return task
 
+    def _get_message_meta(self, task: Task):
+        meta = self._task_meta.pop(task.uuid, None)
+        if not meta:
+            self.logger.error(f"no metadata for given task '{task.task_type} (uuid={task.uuid})'")
+            raise KeyError()
+
+        tp = TopicPartition(meta[0], meta[1])
+        offset = meta[2]
+        return tp, offset
+
     async def commit(self, task: Task, timeout: float = None):
         """
         Commits given task on Kafka by committing topic-partition task came from at
@@ -188,13 +198,7 @@ class AsyncKafkaSubscriber(AsyncSubscriber):
         :param timeout:
         :return:
         """
-        meta = self._task_meta.pop(task.uuid, None)
-        if not meta:
-            self.logger.error(f"no metadata for given task '{task.task_type} (uuid={task.uuid})'")
-            raise KeyError()
-
-        tp = TopicPartition(meta[0], meta[1])
-        offset = meta[2]
+        tp, offset = self._get_message_meta(task)
 
         try:
             # commit message
@@ -212,6 +216,14 @@ class AsyncKafkaSubscriber(AsyncSubscriber):
             self.consumer.resume(tp)
             self.logger.debug(f"{tp} resumed")
 
+    async def rollback(self, task: Task, timeout: float = None):
+        tp, offset = self._get_message_meta(task)
+        # seek just before rollback message
+        self.consumer.seek(tp, offset)
+        # and resume partition
+        self.consumer.resume(tp)
+        self.logger.debug(f"{tp} resumed")
+
     async def handle_partitions_revoke(self, revoked):
         """
         Called after consumer stop fetching messages from Kafka but BEFORE rebalance starts.
@@ -430,11 +442,7 @@ class AssignKafkaSubscriber(AsyncKafkaSubscriber):
             await super().commit(task, timeout)
         else:
             # no commits if no consumer group, just resume paused TP
-            meta = self._task_meta.pop(task.uuid, None)
-            if not meta:
-                self.logger.error(f"no metadata for given task '{task.task_type} (uuid={task.uuid})'")
-                raise KeyError()
+            tp, _ = self._get_message_meta(task)
 
-            tp = TopicPartition(meta[0], meta[1])
             self.consumer.resume(tp)
             self.logger.debug(f"{tp} resumed")
